.. SPDX-FileCopyrightText: 2023-2024 Anna <cyber@sysrq.in>
.. SPDX-License-Identifier: WTFPL
.. No warranty.

Introduction
============

gentle is a :file:`metadata.xml` generator for Gentoo ebuilds.

If you want to learn about how to use gentle, check out the following resources:

* :doc:`installation`
* :doc:`getting-started`

If you need help, or want to talk to the developers, use our chat rooms:

* IRC: `#gentle`_ at ``irc.libera.chat``
* Matrix: `#gentle:sysrq.in`_

.. _#gentle: https://web.libera.chat/?channels=#gentle
.. _#gentle\:sysrq.in: https://matrix.to/#/#gentle:sysrq.in

If you find any bugs, please report them on `Bugzilla`_.

.. _Bugzilla: https://bugs.sysrq.in/enter_bug.cgi?product=Software&component=gentle
